@@ -22,6 +22,14 @@ class JMan:
     def clients(self):
         return accions.Clients(con=self._con)
 
+    @property
+    def tercers(self):
+        return accions.Tercers(con=self._con)
+
+    @property
+    def repartidors(self):
+        return accions.Repartidors(con=self._con)
+
     @property
     def articles(self):
         return accions.Articles(con=self._con)
