@@ -11,6 +11,7 @@ class Comandes:
     _url_cancelar = '/comandes/{id_com}/cancelar'
     _url_tancar = '/comandes/{id_com}/tancar'
     _url_albarans = '/comandes/{id_com}/albarans/iniciats'
+    _url_comanda_distribucio = '/comandes/{id_com}/distribucio'
 
     def __init__(self, con: JManCon):
         self._con = con
@@ -51,3 +52,8 @@ class Comandes:
     def tancar(self, comanda_id: int):
         req = self._con.post(url=Comandes._url_tancar.format(id_com=comanda_id))
         return req.json()
+
+    def put_comanda_distribucio(self, comanda_distribucio: dict):
+        tmp_url = Comandes._url_comanda_distribucio.format(id_com=comanda_distribucio["comanda_id"])
+        req = self._con.put(url=tmp_url, data=comanda_distribucio)
+
